package cn.com.qmth.markingaudit.service.impl;

import java.util.concurrent.TimeUnit;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qmth.boot.core.exception.StatusException;
import com.qmth.boot.core.security.annotation.AuthorizationComponent;
import com.qmth.boot.core.security.service.AuthorizationService;
import com.qmth.boot.core.solar.model.OrgInfo;
import com.qmth.boot.tools.signature.SignatureType;

import cn.com.qmth.markingaudit.service.MonitorService;
import cn.com.qmth.markingaudit.support.AccessInfo;
import cn.com.qmth.markingaudit.support.CustConstants;

@Service
@AuthorizationComponent(prefix = { CustConstants.URI_PREFIX }, type = SignatureType.SECRET)
public class AuthServiceImpl implements AuthorizationService<AccessInfo> {

    @Autowired
    private CaffeineCacheService caffeineCacheService;

    @Autowired
    private MonitorService monitorService;

    @Override
    public AccessInfo findByIdentity(String identity, SignatureType signatureType, String path) {
        String secret = caffeineCacheService.get(identity);
        if (secret == null) {
            OrgInfo org = getOrgInfo(identity);
            if (org == null) {
                throw new StatusException("未找到学校信息,code错误");
            }
            secret = org.getThirdPartySecret();
            caffeineCacheService.set(identity, secret, 5, TimeUnit.MINUTES);
        }
        return new AccessInfo(identity, secret);
    }

    private OrgInfo getOrgInfo(String schoolCode) {
        return monitorService.getOrgInfo(schoolCode);
    }
}